{% extends "allianceauth/base.html" %}
{% load staticfiles %}
{% load i18n %}

{% block page_title %}{% trans "View Notification" %}{% endblock page_title %}

{% block content %}

    <div class="col-lg-12">
        <h1 class="page-header text-center">
            {% trans "View Notification" %}
            <div class="text-right">
                <a href="{% url 'notifications:list' %}" class="btn btn-primary btn-lg">
                    <span class="glyphicon glyphicon-arrow-left"></span>
                </a>
            </div>
        </h1>
        <div class="col-lg-12 container">
            <div class="row">
                <div class="col-lg-12">
                    <div class="panel panel-{{ notif.level }}">
                        <div class="panel-heading">{{ notif.timestamp }} {{ notif.title }}</div>
                        <div class="panel-body"><pre>{{ notif.message }}</pre></div>
                    </div>
                </div>
            </div>
        </div>
    </div>
{% endblock %}
