{% extends "allianceauth/base.html" %}
{% load bootstrap %}
{% load staticfiles %}
{% load i18n %}

{% block page_title %}Characters - FleetUp{% endblock page_title %}

{% block content %}
<div class="col-lg-12">
{% if perms.auth.corp_stats %}
    {% include "fleetup/menu.html" %}
    <div class="panel panel-default">
        <div class="panel-heading">
            <h3 class="panel-title">{% trans "Characters registered on Fleet-Up.com" %}</h3>
        </div>
            <div class="panel-body">
                <div class="col-lg-6">
                    <div class="table-responsive">   
                    <table class="table table-condensed table-hover table-striped">
                        <tr>
                            <th class="col-md-1"></th>
                            <th class="col-md-1">{% trans "Character" %}</th>
                            <th class="col-md-1">{% trans "Corporation" %}</th>
                            <th class="col-md-1">Fleet-Up(id)</th>
                        </tr>
                        {% for char_name, user_id in member_list %}
                        <tr>
                            <td>
                                <img src="http://image.eveonline.com/Character/{{ user_id.char_id }}_32.jpg" class="img-circle">
                            </td>
                            <td>
                                <p>{{ user_id.char_name }}</p>
                            </td>
                            <td>
                                <p>{{ user_id.corporation }}</p>
                            </td>
                            <td>
                                <p>{{ user_id.user_id }}</p>
                            </td>
                        {% endfor %}
                    </table>
                    </div>
                </div>
            </div>
    </div>
{% endif %}
</div>
{% endblock content %}
