{% load i18n %}


<tr>
    <td class="text-center">Discord</td>
    <td class="text-center"></td>
    <td class="text-center"><a href="https://discordapp.com/channels/{{ DISCORD_SERVER_ID }}/{{ DISCORD_SERVER_ID}}">https://discordapp.com</a></td>
    <td class="text-center">
        {% if not discord_uid %}
            <a href="{% url 'discord:activate' %}" title="Activate" class="btn btn-warning">
                <span class="glyphicon glyphicon-ok"></span>
            </a>
        {% else %}
            <a href="{% url 'discord:reset' %}" title="Reset" class="btn btn-primary">
                <span class="glyphicon glyphicon-refresh"></span>
            </a>
            <a href="{% url 'discord:deactivate' %}" title="Deactivate" class="btn btn-danger">
                <span class="glyphicon glyphicon-remove"></span>
            </a>
        {% endif %}
        {% if request.user.is_superuser %}
            <div class="text-center" style="padding-top:5px;">
                <a type="button" class="btn btn-success" href="{% url 'discord:add_bot' %}">{% trans "Link Discord Server" %}</a>
            </div>
        {% endif %}
    </td>
</tr>
