{% extends "allianceauth/base.html" %}
{% load staticfiles %}
{% load i18n %}

{% block page_title %}{% trans "Services Management" %}{% endblock page_title %}
{% block extra_css %}{% endblock extra_css %}

{% block content %}
    <div class="col-lg-12">
    <h1 class="page-header text-center">{% trans "Available Services" %}</h1>
        <table class="table table-hover">
            <tr>
                <th class="text-center">{% trans "Service" %}</th>
                <th class="text-center">{% trans "Username" %}</th>
                <th class="text-center">{% trans "Domain" %}</th>
                <th class="text-center">{% trans "Action" %}</th>
            </tr>
            {% for svc in service_ctrls %}
                {{ svc }}
            {% endfor %}
        </table>
    </div>

{% endblock content %}
