# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-09-09 23:22
from __future__ import unicode_literals

from django.db import migrations
from django.conf import settings

class Migration(migrations.Migration):

    dependencies = [
        ('groupmanagement', '0002_auto_20160906_2354'),
    ]

    operations = []
